<?php

namespace Wilsonwaldo\Sisep\Http\Controllers;

use App\Http\Controllers\ResourceController as BaseController;
use Form;
use Wilsonwaldo\Sisep\Http\Requests\EnlacesRequest;
use Wilsonwaldo\Sisep\Interfaces\EnlacesRepositoryInterface;
use Wilsonwaldo\Sisep\Models\Enlaces;

/**
 * Resource controller class for enlaces.
 */
class EnlacesResourceController extends BaseController
{

    /**
     * Initialize enlaces resource controller.
     *
     * @param type EnlacesRepositoryInterface $enlaces
     *
     * @return null
     */
    public function __construct(EnlacesRepositoryInterface $enlaces)
    {
        parent::__construct();
        $this->repository = $enlaces;
        $this->repository
            ->pushCriteria(\Litepie\Repository\Criteria\RequestCriteria::class)
            ->pushCriteria(\Wilsonwaldo\Sisep\Repositories\Criteria\EnlacesResourceCriteria::class);
    }

    /**
     * Display a list of enlaces.
     *
     * @return Response
     */
    public function index(EnlacesRequest $request)
    {
        $view = $this->response->theme->listView();

        if ($this->response->typeIs('json')) {
            $function = camel_case('get-' . $view);
            return $this->repository
                ->setPresenter(\Wilsonwaldo\Sisep\Repositories\Presenter\EnlacesPresenter::class)
                ->$function();
        }

        $enlaces = $this->repository->paginate();

        return $this->response->title(trans('sisep::enlaces.names'))
            ->view('sisep::enlaces.index', true)
            ->data(compact('enlaces'))
            ->output();
    }

    /**
     * Display enlaces.
     *
     * @param Request $request
     * @param Model   $enlaces
     *
     * @return Response
     */
    public function show(EnlacesRequest $request, Enlaces $enlaces)
    {

        if ($enlaces->exists) {
            $view = 'sisep::enlaces.show';
        } else {
            $view = 'sisep::enlaces.new';
        }

        return $this->response->title(trans('app.view') . ' ' . trans('sisep::enlaces.name'))
            ->data(compact('enlaces'))
            ->view($view, true)
            ->output();
    }

    /**
     * Show the form for creating a new enlaces.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function create(EnlacesRequest $request)
    {

        $enlaces = $this->repository->newInstance([]);
        return $this->response->title(trans('app.new') . ' ' . trans('sisep::enlaces.name')) 
            ->view('sisep::enlaces.create', true) 
            ->data(compact('enlaces'))
            ->output();
    }

    /**
     * Create new enlaces.
     *
     * @param Request $request
     *
     * @return Response
     */
    public function store(EnlacesRequest $request)
    {
        try {
            $attributes              = $request->all();
            $attributes['user_id']   = user_id();
            $attributes['user_type'] = user_type();
            $enlaces                 = $this->repository->create($attributes);

            return $this->response->message(trans('messages.success.created', ['Module' => trans('sisep::enlaces.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('sisep/enlaces/' . $enlaces->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('/sisep/enlaces'))
                ->redirect();
        }

    }

    /**
     * Show enlaces for editing.
     *
     * @param Request $request
     * @param Model   $enlaces
     *
     * @return Response
     */
    public function edit(EnlacesRequest $request, Enlaces $enlaces)
    {
        return $this->response->title(trans('app.edit') . ' ' . trans('sisep::enlaces.name'))
            ->view('sisep::enlaces.edit', true)
            ->data(compact('enlaces'))
            ->output();
    }

    /**
     * Update the enlaces.
     *
     * @param Request $request
     * @param Model   $enlaces
     *
     * @return Response
     */
    public function update(EnlacesRequest $request, Enlaces $enlaces)
    {
        try {
            $attributes = $request->all();

            $enlaces->update($attributes);
            return $this->response->message(trans('messages.success.updated', ['Module' => trans('sisep::enlaces.name')]))
                ->code(204)
                ->status('success')
                ->url(guard_url('sisep/enlaces/' . $enlaces->getRouteKey()))
                ->redirect();
        } catch (Exception $e) {
            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('sisep/enlaces/' . $enlaces->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove the enlaces.
     *
     * @param Model   $enlaces
     *
     * @return Response
     */
    public function destroy(EnlacesRequest $request, Enlaces $enlaces)
    {
        try {

            $enlaces->delete();
            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('sisep::enlaces.name')]))
                ->code(202)
                ->status('success')
                ->url(guard_url('sisep/enlaces/0'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->code(400)
                ->status('error')
                ->url(guard_url('sisep/enlaces/' . $enlaces->getRouteKey()))
                ->redirect();
        }

    }

    /**
     * Remove multiple enlaces.
     *
     * @param Model   $enlaces
     *
     * @return Response
     */
    public function delete(EnlacesRequest $request, $type)
    {
        try {
            $ids = hashids_decode($request->input('ids'));

            if ($type == 'purge') {
                $this->repository->purge($ids);
            } else {
                $this->repository->delete($ids);
            }

            return $this->response->message(trans('messages.success.deleted', ['Module' => trans('sisep::enlaces.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('sisep/enlaces'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/sisep/enlaces'))
                ->redirect();
        }

    }

    /**
     * Restore deleted enlaces.
     *
     * @param Model   $enlaces
     *
     * @return Response
     */
    public function restore(EnlacesRequest $request)
    {
        try {
            $ids = hashids_decode($request->input('ids'));
            $this->repository->restore($ids);

            return $this->response->message(trans('messages.success.restore', ['Module' => trans('sisep::enlaces.name')]))
                ->status("success")
                ->code(202)
                ->url(guard_url('/sisep/enlaces'))
                ->redirect();

        } catch (Exception $e) {

            return $this->response->message($e->getMessage())
                ->status("error")
                ->code(400)
                ->url(guard_url('/sisep/enlaces/'))
                ->redirect();
        }

    }

}
